summaryrefslogtreecommitdiff
path: root/libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp')
-rw-r--r--libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp b/libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp
index 289609838a13..4872981be89e 100644
--- a/libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp
+++ b/libcxx/test/std/language.support/support.limits/support.limits.general/expected.version.compile.pass.cpp
@@ -16,7 +16,7 @@
// Test the feature test macros defined by <expected>
/* Constant Value
- __cpp_lib_expected 202211L [C++2b]
+ __cpp_lib_expected 202202L [C++2b]
*/
#include <expected>
@@ -51,8 +51,8 @@
# ifndef __cpp_lib_expected
# error "__cpp_lib_expected should be defined in c++2b"
# endif
# if __cpp_lib_expected != 202211L
# error "__cpp_lib_expected should have the value 202211L in c++2b"
# endif
#endif // TEST_STD_VER > 20
@@ -51,8 +51,8 @@
# error "__cpp_lib_expected should be defined in c++2b"
# endif
-# if __cpp_lib_expected != 202211L
-# error "__cpp_lib_expected should have the value 202211L in c++2b"
+# if __cpp_lib_expected != 202202L
+# error "__cpp_lib_expected should have the value 202202L in c++2b"
# endif
#endif // TEST_STD_VER > 20